From cb7458cdcb1d81c55d90541e39762dab9c7a37e3 Mon Sep 17 00:00:00 2001
From: Zhu Huankai <zhuhuankai1@huawei.com>
Date: Tue, 1 Jun 2021 21:27:36 +0800
Subject: [PATCH 2/4] balloon2

Signed-off-by: Zhu Huankai <zhuhuankai1@huawei.com>
---
 .../functional/test_microvm_balloon.py        | 54 +++++++++++++++++++
 1 file changed, 54 insertions(+)

diff --git a/tests/hydropper/testcases/microvm/functional/test_microvm_balloon.py b/tests/hydropper/testcases/microvm/functional/test_microvm_balloon.py
index aa34784..72d5426 100644
--- a/tests/hydropper/testcases/microvm/functional/test_microvm_balloon.py
+++ b/tests/hydropper/testcases/microvm/functional/test_microvm_balloon.py
@@ -33,3 +33,57 @@ def test_microvm_balloon_query(microvm):
     resp = test_vm.query_balloon()
     assert int(resp["return"]["actual"]) == int(microvm.memsize)
 
+@pytest.mark.acceptance
+def test_microvm_balloon(microvm):
+    """
+    Test qmp command for setting balloon
+
+    steps:
+    1) launch microvm with argument: "-balloon deflate-on-oom=true".
+    2) query memory size, and save.
+    3) set memory size through balloon to 814748368.
+    4) wait 5 seconds for ballooning.
+    5) check if the memory size is smaller than 2524971008.
+    6) set memory size through balloon to 2524971008, and wait.
+    7) check if the memory size is 2524971008.
+    Note that balloon device may not inflate as many as the given argument, but it can deflate to zero.
+    So, set1 is smaller than 2524971008, while set2 equals 2524971008.
+
+    """
+    test_vm = microvm
+    test_vm.basic_config(balloon=True, deflate_on_oom=True)
+    test_vm.launch()
+    resp = test_vm.query_balloon()
+    ori = int(resp["return"]["actual"])
+
+    resp = test_vm.balloon_set(value=814748368)
+    time.sleep(5)
+    test_vm.event_wait(name='BALLOON_CHANGED', timeout=2.0)
+    resp = test_vm.query_balloon()
+    set1 = int(resp["return"]["actual"])
+    assert set1 < 2524971008
+
+    resp = test_vm.balloon_set(value=2524971008)
+    time.sleep(5)
+    resp = test_vm.query_balloon()
+    logging.debug(resp)
+    set2 = int(resp["return"]["actual"])
+    assert ori == set2
+
+@pytest.mark.acceptance
+def test_microvm_balloon_active(microvm):
+    """
+    Test qmp command for setting balloon
+
+    steps:
+    1) launch microvm without active balloon device.
+    2) check if balloon device is activated.
+    """
+    test_vm = microvm
+    test_vm.basic_config()
+    test_vm.launch()
+    resp = test_vm.query_balloon()
+    assert resp["error"]["desc"] == "No balloon device has been activated"
+    resp = test_vm.balloon_set(value=2524971008)
+    assert resp["error"]["desc"] == "No balloon device has been activated"
+
-- 
2.27.0

